visualization
=============

This module generate an interactive dashboard to visualize user patterns.

.. image:: ../_static/bandicoot-dashboard.png

.. currentmodule:: bandicoot.visualization

.. autosummary::
   :toctree: generated/

   run
   export
   user_data
